"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.dismissLoadingSnackBar = exports.closeSnackBar = exports.updateSnackBar = exports.flashMessageStyle = void 0;
var react_native_flash_message_1 = require("react-native-flash-message");
var react_native_1 = require("react-native");
var text_1 = __importDefault(require("./text"));
var text_button_1 = __importDefault(require("./text-button"));
var error_symbol_1 = require("./icons/error-symbol");
var clear_symbol_1 = require("./icons/clear-symbol");
var spinner_1 = __importDefault(require("./spinner"));
var react_1 = __importDefault(require("react"));
// 스타일 및 아이콘 설정
var getVariantStyles = function (variant) {
    switch (variant) {
        case 'success':
            return {
                backgroundColor: 'bg-emerald-50',
                textColor: 'emerald-700',
                icon: 'check-circle',
            };
        case 'danger':
            return {
                backgroundColor: 'bg-red-50',
                textColor: 'red-700',
                icon: 'error',
            };
        default:
            return {
                backgroundColor: 'bg-gray-50',
                textColor: 'gray-700',
                icon: 'info',
            };
    }
};
// App.tsx에서 사용할 스타일 설정
exports.flashMessageStyle = {
    backgroundColor: 'transparent',
    padding: 0,
    margin: 0,
    width: 'auto',
};
var CustomSnackBarContent = function (_a) {
    var message = _a.message, _b = _a.variant, variant = _b === void 0 ? 'default' : _b, _c = _a.loading, loading = _c === void 0 ? false : _c, _d = _a.buttonText, buttonText = _d === void 0 ? '확인' : _d, _e = _a.styleTheme, styleTheme = _e === void 0 ? 'dark' : _e, _f = _a.rightTextButton, rightTextButton = _f === void 0 ? false : _f, thumbnailProps = _a.thumbnailProps, className = _a.className;
    var styles = getVariantStyles(variant);
    var renderIcon = function () {
        if (loading) {
            return (<react_native_1.View>
          <spinner_1.default size="xsmall"/>
        </react_native_1.View>);
        }
        switch (variant) {
            case 'danger':
                return <error_symbol_1.ErrorSymbolIcon />;
            case 'success':
                return <clear_symbol_1.ClearSymbolIcon />;
            default:
                return null;
        }
    };
    if (variant === 'thumbnail' && thumbnailProps) {
        return (<react_native_1.View className={"\n          flex-row items-center justify-between \n          min-h-[60px]\n          p-[16px]\n          ".concat(styleTheme === 'dark' ? 'bg-gray-900' : 'bg-white', "\n          rounded-xl \n          shadow-lg\n          ").concat(className, "\n        ")}>
        <react_native_1.View className={"flex-row items-center flex-1 ".concat(rightTextButton ? 'mr-[8px]' : '')}>
          <react_native_1.Image source={{
                uri: thumbnailProps.imageUrl || '',
            }} className="w-[42px] h-[42px] rounded-[6px]"/>
          <react_native_1.View className="ml-[12px] flex-1">
            <text_1.default face="body" size="large" weight="bold" textColor={styleTheme === 'dark' ? 'white' : 'black'}>
              {thumbnailProps.title}
            </text_1.default>
            <text_1.default face="body" size="small" weight="regular" textColor={styleTheme === 'dark' ? 'gray-400' : 'gray-600'} className="mt-[2px]">
              {thumbnailProps.description}
            </text_1.default>
          </react_native_1.View>
        </react_native_1.View>

        {rightTextButton && (<text_button_1.default text={buttonText} variant="brand" underline={true} onPress={function () { return (0, react_native_flash_message_1.hideMessage)(); }} size="medium"/>)}
      </react_native_1.View>);
    }
    return (<react_native_1.View className={"\n      flex-row items-center justify-between \n      min-h-[60px]\n      p-[16px]\n      ".concat(styleTheme === 'dark' ? 'bg-gray-900' : 'bg-white', "\n      rounded-xl \n      shadow-lg\n      w-auto\n      ").concat(className, "\n    ")} style={{ alignSelf: 'center' }}>
      <react_native_1.View className="flex-row items-center">
        {renderIcon()}
        <text_1.default face="body" size="large" weight="regular" textColor={styleTheme === 'dark' ? 'white' : 'black'} className="ml-[6px]">
          {message}
        </text_1.default>
      </react_native_1.View>

      {rightTextButton && (<text_button_1.default text={buttonText} variant="brand" underline={true} onPress={function () { return (0, react_native_flash_message_1.hideMessage)(); }} size="medium"/>)}
    </react_native_1.View>);
};
// 현재 스낵바 상태 관리 변수
var isSnackBarVisible = false;
var currentSnackBarId = null;
var isSwitchingSnackBar = false;
var showSnackBar = function (_a) {
    var message = _a.message, _b = _a.variant, variant = _b === void 0 ? 'default' : _b, _c = _a.loading, loading = _c === void 0 ? false : _c, _d = _a.buttonText, buttonText = _d === void 0 ? '확인' : _d, _e = _a.duration, duration = _e === void 0 ? loading ? 0 : 3000 : _e, _f = _a.rightTextButton, rightTextButton = _f === void 0 ? false : _f, _g = _a.styleTheme, styleTheme = _g === void 0 ? 'dark' : _g, thumbnailProps = _a.thumbnailProps, className = _a.className;
    // 이미 전환 중이면 무시
    if (isSwitchingSnackBar)
        return;
    // 전환 중 상태로 설정
    isSwitchingSnackBar = true;
    var displayNewSnackBar = function () {
        // 상태 업데이트
        isSnackBarVisible = true;
        currentSnackBarId = Date.now();
        isSwitchingSnackBar = false;
        // 스낵바 설정
        var commonConfig = {
            message: '',
            duration: duration,
            backgroundColor: 'transparent',
            hideStatusBar: false,
            autoHide: !loading,
            hideOnPress: !loading,
            animated: true,
            animationDuration: 150,
            renderCustomContent: function () { return (<CustomSnackBarContent message={message} variant={variant} styleTheme={styleTheme} loading={loading} buttonText={buttonText} rightTextButton={rightTextButton} thumbnailProps={thumbnailProps} className={className}/>); },
            onPress: loading ? function () { } : function () { return (0, react_native_flash_message_1.hideMessage)(); },
            onHide: function () {
                isSnackBarVisible = false;
                currentSnackBarId = null;
            },
        };
        (0, react_native_flash_message_1.showMessage)(commonConfig);
    };
    if (isSnackBarVisible) {
        (0, react_native_flash_message_1.hideMessage)();
        // 기존 스낵바가 완전히 사라질 시간을 더 충분히 확보
        setTimeout(displayNewSnackBar, 250);
    }
    else {
        displayNewSnackBar();
    }
};
// 스낵바 상태를 업데이트하는 함수
var updateSnackBar = function (props) {
    showSnackBar(props);
};
exports.updateSnackBar = updateSnackBar;
// 스낵바를 명시적으로 닫는 함수
var closeSnackBar = function () {
    if (isSnackBarVisible) {
        (0, react_native_flash_message_1.hideMessage)();
        isSnackBarVisible = false;
        currentSnackBarId = null;
        isSwitchingSnackBar = false;
    }
};
exports.closeSnackBar = closeSnackBar;
// 로딩 중인 스낵바만 즉시 닫는 함수
var dismissLoadingSnackBar = function () {
    if (isSnackBarVisible) {
        (0, react_native_flash_message_1.hideMessage)();
        isSnackBarVisible = false;
        currentSnackBarId = null;
        isSwitchingSnackBar = false;
    }
};
exports.dismissLoadingSnackBar = dismissLoadingSnackBar;
exports.default = showSnackBar;
//# sourceMappingURL=snack-bar.js.map