import React from 'react';
import {
  ColorValue,
  Dimensions,
  InteractionManager,
  Platform,
  StyleSheet,
  View,
} from 'react-native';
import WebView from 'react-native-webview';
import { BlurView as RNBlurView } from '@react-native-community/blur';

export interface BlurViewProps {
  /**
   * @example rgba(0, 0, 0, 0.5)
   * @default "rgba(255, 255, 255, 0.8)"
   */
  backgroundColor?: ColorValue;
  /**
   * - px 단위
   * @default 10
   */
  blurRadius?: number;
  /**
   * @default 1000
   */
  zIndex?: number;
  blur?: boolean;
}

const BlurView: React.FC<BlurViewProps> = ({
  backgroundColor = 'rgba(3, 24, 50, 0.46)',
  blurRadius = 10,
  zIndex = 1000,
  blur = false,
}) => {
  if (Platform.OS === 'android') {
    return (
      <RNBlurView
        style={{
          position: 'absolute',
          top: 0,
          left: 0,
          bottom: 0,
          right: 0,
          backgroundColor: backgroundColor,
          zIndex: zIndex,
        }}
        blurType="dark"
        blurAmount={blurRadius}
        overlayColor={String(backgroundColor)}
      />
    );
  }

  return (
    <View
      style={[
        StyleSheet.absoluteFill,
        {
          backgroundColor: '#00000000',
          overflow: 'hidden',
          zIndex: zIndex,
        },
      ]}
    >
      <WebView
        style={{
          width: '100%',
          height: '100%',
          backgroundColor: '#00000000',
        }}
        originWhitelist={['*']}
        overScrollMode="never"
        scrollEnabled={false}
        source={{
          html: `
						<html>
							<head>
								<meta name="viewport" content="initial-scale=1.0 maximum-scale=1.0" />
								<style>
									.blur {
										position: absolute;
										top: 0;
										right:0;
										bottom: 0;
										left: 0;
										height: ${Dimensions.get('screen').height}px;
										background: ${String(backgroundColor)};
										-webkit-backdrop-filter: blur(${blur ? blurRadius : 0}px);
										backdrop-filter: blur(${blur ? blurRadius : 0}px);
									}
								</style>
							</head>
							<body>
								<div class="blur" />
							</body>
						</html>
					`,
        }}
      />
    </View>
  );
};

export default BlurView;
